@@ -3,7 +3,7 @@
 Allows you to control and interact with the FL Studio Channel Rack, and with
 instrument channels.
 
-## NOTES:
+## NOTE:
  * In this documentation, an index respects channel groups, whereas a
    global index does not.
 
@@ -14,19 +14,20 @@ import midi
 
 
 def channelNumber(canBeNone: int = 0, offset: int = 0) -> int:
-    """Returns the global index of the first selected channel, otherwise the nth
-    selected channel where n is `offset` + 1. If n is greater than the number of
-    selected channels, the global index of the last selected channel will be
-    returned.
+    """Returns the global index of the first selected channel, otherwise the
+    nth selected channel where n is `offset` + 1. If n is greater than the
+    number of selected channels, the global index of the last selected channel
+    will be returned.
 
-    If `canBeNone` is `1`, no selection will return `-1`. Otherwise, no selection
-    will return `0` (representing the first channel).
+    If `canBeNone` is `1`, no selection will return `-1`. Otherwise, no
+    selection will return `0` (representing the first channel).
 
     ## Args:
-     * `canBeNone` (`int`, optional): Whether the function will return `-1` or `0`
-       when there is no selection. Defaults to `0` (returning `0`).
+     * `canBeNone` (`int`, optional): Whether the function will return `-1` or
+       `0` when there is no selection. Defaults to `0` (returning `0`).
 
-     * `offset` (`int`, optional): return other selected channels after offset. Defaults to 0.
+     * `offset` (`int`, optional): return other selected channels after offset.
+       Defaults to 0.
 
     ## Returns:
      * `int`: global index of first selected channel
@@ -37,12 +38,12 @@ def channelNumber(canBeNone: int = 0, offset: int = 0) -> int:
 
 
 def channelCount(mode: int = 0) -> int:
-    """Returns the number of channels on the channel rack. Respect for groups is
-    controlled by the `mode` flag.
+    """Returns the number of channels on the channel rack. Respect for groups
+    is controlled by the `mode` flag.
 
     ## Args:
-     * `mode` (`int`, optional): Whether the number of channels respects groups.
-       Defaults to 0.
+     * `mode` (`int`, optional): Whether the number of channels respects
+       groups. Defaults to 0.
 
     ## Returns:
      * `int`: number of channels
@@ -187,7 +188,11 @@ def getChannelVolume(index: int, mode: int = 0) -> float:
     return 0.0
 
 
-def setChannelVolume(index: int, volume: float, pickupMode: int = midi.PIM_None) -> None:
+def setChannelVolume(
+    index: int,
+    volume: float,
+    pickupMode: int = midi.PIM_None
+) -> None:
     """Sets the normalised volume of the channel at `index`, where `0.0` is
     the minimum value, and `1.0` is the maximum value. Note that the default
     volume for channels is `0.78125`. Use the pickup mode flag to set pickup
@@ -240,23 +245,29 @@ def setChannelPan(index: int, pan: float, pickupMode: int = midi.PIM_None) -> No
 
 
 def getChannelPitch(index: int, mode: int = 0) -> 'float | int':
-    """Returns the pitch of the channel at `index`. The `mode` parameter is used
-    to determine the type of pitch returned.
-
-    HELP WANTED: What do the `mode` parameter options mean?
+    """Returns the current pitch bend (or range) of the channel at `index`.
+    The `mode` parameter is used to determine the type of pitch returned.
 
     ## Args:
     * `index` (`int`): index of channel
 
     * `mode` (`int`, optional):
-          * `1`: return value in semitones
+          * `0` (default): return the current pitch bend as a factor of the current
+              range (usually `-1.0` to `1.0`). Larger values might be reached if the
+              pitch is automated with events, for example.
 
-          * `2`: return value pitch range???
+          * `1`: return the current pitch offset in cents.
+              * BUG: Official API docs incorrectly state "semitones".
+
+          * `2`: return the current pitch range in semitones.
+              * BUG: This is not guaranteed to be correct.
+                For more information, see `setChannelPitch` on
+                modifying the pitch range of a channel.
 
     ## Returns:
-     * `float`: channel pitch (when `mode` is `1`)
+     * `float`: channel pitch (when `mode` is `0`)
 
-     * `int`: channel pitch range (when `mode` is `2`) ???
+     * `int`: channel pitch range (when `mode` is `1` or 2)
 
     Included since API version 8
     """
@@ -266,9 +277,7 @@ def getChannelPitch(index: int, mode: int = 0) -> 'float | int':
 def setChannelPitch(index: int, value: float, mode: int = 0, pickupMode: int = midi.PIM_None) -> 'float | int':
     """Sets the pitch of the channel at `index` to value. The `mode` parameter is used
     to determine the type of pitch set. Use the pickup mode flag to set pickup
-    options.
-
-    HELP WANTED: What do the `mode` parameter options mean?
+    options. The final pitch will be clamped to the current pitch range.
 
     ## Args:
      * `index` (`int`): index of channel
@@ -276,9 +285,14 @@ def setChannelPitch(index: int, value: float, mode: int = 0, pickupMode: int = m
      * `value` (`float`): value to set
 
      * `mode` (`int`, optional):
-          * `1`: set value in semitones
+          * `0` (default): set pitch as a factor of the current pitch bend range (between [-1.0, 1.0]).
 
-          * `2`: set value pitch range???
+          * `1`: set pitch in cents
+
+          * `2`: **UTTERLY BROKEN.** Set the pitch range in semitones.
+
+            BUG: This only affects the range reported by `getChannelPitch`.
+            This will desynchronize the reported range from what is visible in the UI.
 
      * `pickupMode` (`int`, optional): define the pickup behaviour. Refer to
        the [manual](https://www.image-line.com/fl-studio-learning/fl-studio-online-manual/html/midi_scripting.htm#pickupModes)
@@ -363,9 +377,10 @@ def selectedChannel(canBeNone: int = 0, offset: int = 0, indexGlobal: int = 0) -
     returned. If `indexGlobal` is set to `1`, this will replicate the behaviour
     of `channelNumber()` by returning global indexes.
 
-    NOTE: This function replaces the functionality of `channelNumber()`
-    entirely, with the added functionality of providing indexes respecting
-    groups (when `indexGlobal` is not set).
+    ## NOTE:
+    * This function replaces the functionality of `channelNumber()`
+      entirely, with the added functionality of providing indexes respecting
+      groups (when `indexGlobal` is not set).
 
     If `canBeNone` is `1`, no selection will return `-1`. Otherwise, no selection
     will return `0` (representing the first channel).
@@ -405,7 +420,10 @@ def deselectAll() -> None:
 def getChannelMidiInPort(index: int) -> int:
     """Returns the MIDI port associated with the channel at `index`.
 
-    TODO: Write use cases
+    This can be used to send data directly to channels that are associated with
+    a MIDI in port. Although channels are unassigned by default, a user can
+    configure plugins to receive MIDI on a certain channel which can unlock
+    many useful plugin-specific features.
 
     ## Args:
      * `index` (`int`): channel index
@@ -413,6 +431,8 @@ def getChannelMidiInPort(index: int) -> int:
     ## Returns:
      * `int`: MIDI port associated with channel
 
+     * `-2`: Channel not assigned to a MIDI port
+
     Included since API version 1
     """
     return 0
@@ -465,10 +485,9 @@ def isHighlighted() -> bool:
 def processRECEvent(eventId: int, value: int, flags: int) -> int:
     """Processes a recording event.
 
-    WARNING: This function is depreciated here, and moved to the `general`
-    module as of API version 7.
-
-    HELP WANTED: What does this do?
+    ## WARNING:
+    * This function is depreciated here, and moved to the `general` module as
+      of API version 7.
 
     ## Args:
      * `eventId` (`int`): Refer to the [official documentation](https://www.image-line.com/fl-studio-learning/fl-studio-online-manual/html/midi_scripting.htm#RecEventParams)
@@ -486,20 +505,30 @@ def processRECEvent(eventId: int, value: int, flags: int) -> int:
     return 0
 
 
-def incEventValue(eventId: int, step: int, res: float) -> int:
-    """Increase recording event value
+def incEventValue(eventId: int, step: int, res: float = 1/24) -> int:
+    """Get event value increased by step. Use (optional) res paremeter to
+    specify increment resolution.
 
-    HELP WANTED: I have no idea what any of this does
+    Use result as new value in processRECEvent
+
+    ## Example usage:
+    ```py
+    # Increase volume of first channel
+    step = 1
+    eventId = midi.REC_Chan_Vol + channels.getRecEventId(0)
+    newValue = channels.incEventValue(eventId, step)
+    general.processRECEvent(eventId, newValue, midi.REC_UpdateValue | midi.REC_UpdateControl)
+    ```
 
     ## Args:
      * `eventId` (`int`): event ID, see the [official documentation](https://www.image-line.com/fl-studio-learning/fl-studio-online-manual/html/midi_scripting.htm#RecEventParams)
 
-     * `step` (`int`): unknown
+     * `step` (`int`): event value increased by step
 
-     * `res` (`float` (double precision)): unknown
+     * `res` (`float`, optional): increment resolution. Defaults to 1/24.
 
     ## Returns:
-     * `int`: unknown
+     * `int`: incremented event value, for use in `general.processRECEvent()`
 
     Included since API version 1
     """
@@ -507,16 +536,15 @@ def incEventValue(eventId: int, step: int, res: float) -> int:
 
 
 def getRecEventId(index: int) -> int:
-    """Returns recording event ID for channel at `index`.
+    """Return the starting point of REC event IDs for the channel at `index`.
 
-    HELP WANTED: Honestly REC events are sooooo confusing, and I avoid using
-    them entirely. Can someone else explain them?
+    See `general.processRECEvent` for more information.
 
     ## Args:
      * `index` (`int`): channel index
 
     ## Returns:
-     * `int`: Recording event ID???
+     * `int`: REC event ID offset for accessing `midi.REC_Chan_*` parameters
 
     Included since API version 1
     """
@@ -557,12 +585,13 @@ def getStepParam(step: int, param: int, ofset: int, startPos: int,
                  padsStride: int = 16) -> int:
     """Get step parameter for `step`.
 
-    HELP WANTED: What does this do?
+    ## HELP WANTED:
+    * What does this do?
 
     ## Args:
      * `step` (`int`): ?
 
-     * `param` (`int`): ?? at least there's the [offical documentation](https://www.image-line.com/fl-studio-learning/fl-studio-online-manual/html/midi_scripting.htm#stepParams)
+     * `param` (`int`): ?? at least there's the [official documentation](https://www.image-line.com/fl-studio-learning/fl-studio-online-manual/html/midi_scripting.htm#stepParams)
        (actually, tbh the docs on this looks kinda dodgy for some values)
 
      * `ofset` (`int`): ??? (this typo is in the official docs too)
@@ -582,10 +611,12 @@ def getStepParam(step: int, param: int, ofset: int, startPos: int,
 def getCurrentStepParam(index: int, step: int, param: int) -> int:
     """Get current step parameter for channel at `index` and for step at `step`.
 
-    HELP WANTED: What does this do?
+    ## HELP WANTED:
+    * What does this do?
 
-    TODO: Official documentation says this returns None, but it actually seems
-    to return an int.
+    ## NOTE:
+    * Official documentation says this returns None, but it actually seems to
+      return an int.
 
     ## Args:
      * `index` (`int`): channel index
@@ -604,8 +635,9 @@ def getGridBitWithLoop(index: int, position: int) -> bool:
     """Get value of grid bit on channel `index` in `position` accounting for
     loops.
 
-    NOTE: Official documentations say this returns None, but it doesn't. This
-    documentation reflects the actual behaviour.
+    ## NOTE:
+    * Official documentations say this returns None, but it doesn't. This
+      documentation reflects the actual behaviour.
 
     ## Args:
      * `index` (`int`): channel index`
@@ -620,6 +652,35 @@ def getGridBitWithLoop(index: int, position: int) -> bool:
     return False
 
 
+def showGraphEditor(
+    temporary: bool,
+    param: int,
+    step: int,
+    index: int,
+    globalIndex: int = 1
+) -> None:
+    """
+    Show the graph editor for a step parameter on the channel at `index`
+
+    ## Args:
+    * `temporary` (`bool`): whether the editor should be temporary or stay open
+
+    * `param` (`int`): [step parameter](https://www.image-line.com/fl-studio-learning/fl-studio-beta-online-manual/html/midi_scripting.htm#stepParams)
+
+    * `step` (`int`): step ???
+
+    * `index` (`int`): index of channel
+
+    * `globalIndex` (`int`, optional): whether index should be global (`1`) or
+        not (`0`). Defaults to `1`.
+
+    Included since API Version 1
+
+    ## API Changes:
+    * v20: Add global index
+    """
+
+
 def showEditor(index: int, value: int = -1) -> None:
     """Toggle whether the plugin window for the channel at `index` is shown.
     The value parameter chan be used to set to a specific value.
@@ -630,7 +691,10 @@ def showEditor(index: int, value: int = -1) -> None:
      * `value` (`int`): whether to hide (`0`) or show (`1`) the plugin window.
        Defaults to `-1` (toggle).
 
-    Included since API version 1, with optional parameter added in version 3.
+    Included since API version 1
+
+    ## API Changes:
+    * v3: Add `value` parameter
     """
 
 
@@ -656,7 +720,10 @@ def showCSForm(index: int, state: int = 1) -> None:
      * `state` (`int`, optional): whether to hide (`0`), show
         (`1`) or toggle (`-1`) the plugin window. Defaults to `1`.
 
-    Included since API version 1, with optional parameter added in version 9
+    Included since API version 1
+
+    ## API Changes:
+    * v9: Add `state` parameter
     """
 
 
@@ -666,14 +733,17 @@ def midiNoteOn(indexGlobal: int, note: int, velocity: int, channel: int = -1
 
     This can be used to create extra notes (eg mapping one note to a chord).
 
+    ## WARNING:
+    * Specifying a `channel` doesn't appear to do anything
+
     ## Args:
-     * `indexGlobal` (`int`): channel index (not respecting groups)
+    * `indexGlobal` (`int`): channel index (not respecting groups)
 
-     * `note` (`int`): note number (0-127)
+    * `note` (`int`): note number (0-127)
 
-     * `velocity` (`int`): note velocity (1-127, 0 is note off)
+    * `velocity` (`int`): note velocity (1-127, 0 is note off)
 
-     * `channel` (`int`, optional): MIDI channel to use. Defaults to -1.
+    * `channel` (`int`, optional): MIDI channel to use. Defaults to -1.
 
     Included since API version 1
     """
@@ -694,12 +764,14 @@ def getActivityLevel(index: int) -> float:
     """
     return 0.0
 
+
 def quickQuantize(index: int, startOnly: int = 1) -> None:
     """
     Perform a quick quantize operation on the channel at index
 
-    NOTE: The API documentation lists this as returning a float, however it
-    actually returns None, which is documented here.
+    ## NOTE:
+    * The API documentation lists this as returning a float, however it
+      actually returns None, which is what is documented here.
 
     ## Args:
     * `index` (`int`): channel index, respecting groups
@@ -708,3 +780,13 @@ def quickQuantize(index: int, startOnly: int = 1) -> None:
 
     Included since API Version 9
     """
+
+def updateGraphEditor() -> None:
+    """
+    ???
+
+    ## WARNING:
+    * This function has no official documentation
+
+    Included since API Version 20?
+    """
